{****************************************************************************
** This is a unit to demonstrate how to access the mouse using Turbo       **
** Pascal. I've decided to call the mouse using assembler statements.      **
** Using the standard Pascal method would require a lot of extra work and  **
** doesn't improve readability.                                            **
****************************************************************************}
unit Mouse;

interface

var
  {Global variables, storing the coordinates and the button press information}
  MouseX, MouseY, MouseB : Word;

function IfMouse : Boolean;
procedure ShowMouse;
procedure HideMouse;
procedure ReadMouse;
procedure SetMouseXY (X, Y : Word);
procedure SetMinMaxX (Min, Max : Word);
procedure SetMinMaxY (Min, Max : Word);

implementation

{This procedure checks whether a mouse is available}
function IfMouse : Boolean; assembler;
asm
  mov ax, 0
  int $33
end;

{This procedure makes the mouse cursor visible}
procedure ShowMouse; assembler;
asm
  mov ax, $1
  int $33
end;

{This procedure makes the mouse cursor invisible}
procedure HideMouse; assembler;
asm
  mov ax, $2
  int $33
end;

{This procedure reads the location of the mouse cursor and the button press
information}
procedure ReadMouse; assembler;
asm
  mov ax, $3
  int $33
  mov MouseB, bx
  mov MouseX, cx
  mov MouseY, dx
end;

{This procedure sets the mouse cursor to another location}
procedure SetMouseXY (X, Y : Word); assembler;
asm
  mov ax, $4
  mov cx, X
  mov dx, Y
  int $33
end;

{This procedure sets the minimum and maximum values that the mouse cursor
may reach in horizontal range}
procedure SetMinMaxX (Min, Max : Word); assembler;
asm
  mov ax, $7
  mov cx, Min
  mov dx, Max
  int $33
end;

{This procedure sets the minimum and maximum values that the mouse cursor
may reach in vertical range}
procedure SetMinMaxY (Min, Max : Word); assembler;
asm
  mov ax, $8
  mov cx, Min
  mov dx, Max
  int $33
end;

end.